Class: Chutney::AvoidMutuallyExclusiveTags

Inherits:
Linter
  • Object
show all
Defined in:
lib/chutney/linter/avoid_mutually_exclusive_tags.rb

Overview

service class to lint for avoiding mutually exclusive tags

Instance Attribute Summary

Attributes inherited from Linter

#configuration, #filename, #issues

Instance Method Summary collapse

Methods inherited from Linter

#add_issue, #and_word?, #background, #background_word?, #but_word?, descendants, #dialect, #dialect_word, #elements, #examples_word?, #feature, #feature_word?, #filled_scenarios, #given_word?, #initialize, linter_name, #linter_name, #location, #off_switch?, #render_step, #render_step_argument, #scenario_outline_word?, #scenarios, #steps, #tags_for, #then_word?, #type, #when_word?

Constructor Details

This class inherits a constructor from Chutney::Linter

Instance Method Details

#lintObject



6
7
8
9
10
11
12
13
14
15
16
17
18
19
# File 'lib/chutney/linter/avoid_mutually_exclusive_tags.rb', line 6

def lint
  return if feature.nil?

  feature_tags = tags_for(feature)
  scenarios do |_feature, scenario|
    scenario_tags = tags_for(scenario)
    # use [nil] for plain scenarios so the loop runs once with no example tags
    examples_blocks = scenario.respond_to?(:examples) ? scenario.examples : [nil]

    tag_groups.each do |group|
      check_group(group, feature_tags, scenario, scenario_tags, examples_blocks)
    end
  end
end